"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteKeysFromObject = exports.filterArrays = exports.getArrayKeys = exports.removeArrays = exports.objectDeepCopy = exports.objectCompare = exports.objectFindKey = exports.objectUpdateDeeply = exports.objectRemoveEmptyDeeply = exports.objectRemoveEmpty = exports.objectMissingValue = exports.objectPick = exports.objectOmit = void 0;
const objectOmit = (obj, ...props) => {
    const result = { ...obj };
    props.forEach(function (prop) {
        delete result[prop];
    });
    return result;
};
exports.objectOmit = objectOmit;
const objectPick = (obj, ...props) => {
    return props.reduce(function (result, prop) {
        result[prop] = obj[prop];
        return result;
    }, {});
};
exports.objectPick = objectPick;
const objectMissingValue = (oldData, newData) => {
    const keys = Object.keys(oldData);
    keys.forEach(key => {
        if (newData[key] === undefined) {
            newData[key] = oldData[key];
        }
    });
    return newData;
};
exports.objectMissingValue = objectMissingValue;
const objectRemoveEmpty = (obj, keys) => {
    keys.forEach(key => {
        if (obj[key] === '' || obj[key] === null || obj[key] === undefined) {
            delete obj[key];
        }
    });
    return obj;
};
exports.objectRemoveEmpty = objectRemoveEmpty;
const objectRemoveEmptyDeeply = (obj) => {
    Object.keys(obj).forEach(key => {
        if (obj[key] && typeof obj[key] === 'object')
            (0, exports.objectRemoveEmptyDeeply)(obj[key]);
        else if (obj[key] === '' || obj[key] === null || obj[key] === undefined)
            delete obj[key];
    });
    return obj;
};
exports.objectRemoveEmptyDeeply = objectRemoveEmptyDeeply;
const objectUpdateDeeply = (obj, key, value) => {
    const newObj = { ...obj };
    const keys = key.split('.');
    const lastKey = keys.pop();
    let currentObj = newObj;
    keys.forEach(key => {
        currentObj[key] = { ...currentObj[key] };
        currentObj = currentObj[key];
    });
    if (lastKey === undefined)
        return newObj;
    currentObj[lastKey] = value;
    return newObj;
};
exports.objectUpdateDeeply = objectUpdateDeeply;
const objectFindKey = (obj, key) => {
    let result = null;
    Object.keys(obj).forEach(k => {
        if (k === key) {
            result = obj[k];
        }
    });
    return result !== null;
};
exports.objectFindKey = objectFindKey;
const objectCompare = (obj1, obj2) => {
    return JSON.stringify(obj1) === JSON.stringify(obj2);
};
exports.objectCompare = objectCompare;
const objectDeepCopy = (obj) => {
    return JSON.parse(JSON.stringify(obj));
};
exports.objectDeepCopy = objectDeepCopy;
const removeArrays = (obj) => {
    for (const key in obj) {
        if (Array.isArray(obj[key])) {
            delete obj[key];
        }
        else if (typeof obj[key] === 'object') {
            (0, exports.removeArrays)(obj[key]);
        }
    }
    return obj;
};
exports.removeArrays = removeArrays;
const getArrayKeys = (obj) => {
    const keys = [];
    for (const key in obj) {
        if (Array.isArray(obj[key])) {
            keys.push(key);
        }
    }
    return keys;
};
exports.getArrayKeys = getArrayKeys;
const filterArrays = (obj) => {
    const newObj = {};
    for (const key in obj) {
        if (Array.isArray(obj[key]) && obj[key].length > 0) {
            newObj[key] = obj[key];
        }
    }
    return newObj;
};
exports.filterArrays = filterArrays;
const deleteKeysFromObject = (obj, keysToDelete) => {
    for (const key of keysToDelete) {
        delete obj[key];
    }
    return obj;
};
exports.deleteKeysFromObject = deleteKeysFromObject;
