import { Button, useTheme, Text, Icon } from "react-native-paper";
import React, { useEffect, useMemo, useState } from "react";
import type { BannerType, IBusiness } from "../typings/business";
import { useLMS } from "../context/context";
import type { BannerDataType } from "../data/banner";
import { BANNER_DATA } from "../data/banner";
import analytics from "../utils/segment";
import { SEGMENT_EVENTS } from "../data/segmentEvents";
import { View, ViewStyle, TouchableOpacity } from "react-native";
import { showMessage, hideMessage } from "react-native-flash-message";
//import Icon from "react-native-vector-icons/Feather";
//import AntIcon from "react-native-vector-icons/AntDesign";
import { COLOR } from "../data/color";
import { SafeAreaView } from "react-native-safe-area-context";

/*const FinanceContainer = styled(FlexRow)<{ color: any }>`
  width: 100%;
  padding: 12px;
  flex-wrap: nowrap;
  align-items: center;
  justify-content: space-between;
  background-color: ${({ color }) => color};
  margin-bottom: 5px;
`;*/

/*const ButtonWrapper = styled(FlexRow)`
  @media screen and (max-width: 800px) {
    display: none;
  }
`;*/

/*const DescriptionButton = styled(FlexRow)`
  @media screen and (min-width: 801px) {
    display: none;
  }
`;

const Wrapper = styled(FlexRow)`
  @media screen and (max-width: 800px) {
    flex-direction: column;
  }
`;

const Gap = styled(FlexRow)`
  width: 8px;
  height: 8px;

  @media screen and (max-width: 800px) {
    width: 6px;
    height: 6px;
  }
`;*/

type OFHeaderProps = {
  onPress?({
    type,
    contractUrl,
  }: {
    type: BannerType;
    contractUrl: string;
  }): void;
  onClose?(): void;
};

export const Banner: React.ComponentType<OFHeaderProps> = ({
  onClose,
  onPress,
}) => {
  const [detail, setDetail] = useState<IBusiness | undefined>();
  const { EMAIL, userDetail } = useLMS();
  const theme = useTheme();

  const status = useMemo(() => {
    let contractUrl, contractValid, reason;
    if (detail) {
      contractUrl = detail.kyb?.facilities.filter(
        (d: any) => d.status === "contract_pending",
      )[0]?.envelope_url;
      contractValid = detail.kyb?.facilities.filter(
        (d: any) => d.status === "contract_valid",
      );
      reason = detail.kyb?.statuses?.filter(
        (d: any) => d.status === "rejected",
      );
    }
    return {
      contractUrl,
      contractValid,
      reason: reason && reason.length > 0 ? reason[0].reason : "",
    };
  }, [detail]);

  useEffect(() => {
    if (!EMAIL) {
      showMessage({ message: "Email is required", type: "danger" });
    } else {
      setDetail(userDetail);
    }
  }, [EMAIL, userDetail]);

  const Render = ({
    data,
    color,
    disabled,
    event,
  }: {
    color?: any;
    data: BannerDataType;
    disabled?: boolean;
    event?: string;
  }) => {
    return (
      <View
        style={{
          ...(styles.financeContainer as ViewStyle),
          backgroundColor: color,
        }}
      >
        <View style={styles.wrapper as ViewStyle}>
          <Icon source={"clock"} size={25} color={color} />

          <View style={styles.flexCol as ViewStyle}>
            <Text variant={"bodyMedium"}>{data.title}</Text>
            <Text variant={"bodySmall"}>{data.description}</Text>
            {data.actionTitle && (
              <>
                <Button
                  disabled={!!disabled}
                  mode={"contained"}
                  onPress={() => {
                    onPress?.({
                      type: data.type,
                      contractUrl: status.contractUrl || "",
                    });
                  }}
                >
                  {data.actionTitle}
                </Button>
              </>
            )}
          </View>
        </View>
        <View
          style={{
            ...(styles.flexRow as ViewStyle),
            alignSelf: "flex-start",
            alignItems: "flex-start",
          }}
        >
          {data.actionTitle && (
            <Button
              mode={"contained"}
              disabled={!!disabled}
              onPress={() => {
                if (event) {
                  analytics.track(event);
                }
                onPress?.({
                  type: data.type,
                  contractUrl: status.contractUrl || "",
                });
              }}
            >
              {data.actionTitle}
            </Button>
          )}
          <TouchableOpacity
            onPress={() => {
              onClose?.();
            }}
          >
            <Icon source={"close"} size={25} />
          </TouchableOpacity>
        </View>
      </View>
    );
  };

  return (
    <>
      {detail && (
        <>
          {!detail.kyb && (
            <Render
              data={BANNER_DATA().REGISTER as BannerDataType}
              color={COLOR.info}
            />
          )}
          {detail.kyb && detail.kyb.status === "pending" && (
            <Render
              data={BANNER_DATA().PENDING as BannerDataType}
              color={COLOR.warning}
            />
          )}
          {detail.kyb &&
            detail.kyb.status === "approved" &&
            status.contractValid?.length === 0 && (
              <Render
                data={
                  BANNER_DATA(
                    undefined,
                    !status.contractUrl
                      ? "You will receive contract soon"
                      : "Review and sign contract",
                  ).APPROVED as BannerDataType
                }
                color={COLOR.info}
                disabled={!status.contractUrl}
                event={SEGMENT_EVENTS.CLICK_SIGN_CONTRACT}
              />
            )}
          {detail.kyb && detail.kyb.status === "rejected" && (
            <Render
              data={BANNER_DATA(status?.reason).REJECTED as BannerDataType}
              color={COLOR.error}
              event={SEGMENT_EVENTS.CLICK_KYC_REGISTRATION}
            />
          )}
        </>
      )}
    </>
  );
};

const styles = {
  financeContainer: {
    display: "flex",
    flexDirection: "row",
    width: "100%",
    padding: 12,
    flexWrap: "nowrap",
    alignItems: "center",
    justifyContent: "space-between",
    marginBottom: 5,
  },
  buttonWrapper: {
    display: "flex",
    flexDirection: "row",
  },
  gap: {
    width: 8,
    height: 8,
  },
  wrapper: {
    flexDirection: "column",
  },
  flexRow: {
    display: "flex",
    flexDirection: "row",
  },
  flexCol: {
    display: "flex",
    flexDirection: "column",
  },
};
